# -*- coding: utf-8 -*-

#   This file is part of emesene.
#
#    Emesene is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    emesene is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with emesene; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

import gtk
import Theme
from gobject import timeout_add, source_remove

class SmilieWindow( gtk.Window ):
	"""
	this is the window that opens when you press the smilie button on the
	conversation window
	"""

	def __init__( self, theme , callback, parent=None ):

		gtk.Window.__init__( self )
		self.set_decorated( False )
		self.set_type_hint( gtk.gdk.WINDOW_TYPE_HINT_DIALOG )
#		self.set_modal( True ) # causes weird enter/leave events
		if parent:
			self.set_transient_for( parent )
		self.set_position( gtk.WIN_POS_MOUSE )
		self.set_resizable( False )
		self.set_title( _("Smilies") )
		self.set_border_width( 2 )

		self.callback = callback

		table = gtk.Table()

		self.closed = True

		x = 0
		y = 0

		for i in theme.getSingleSmileysList():
			if x == 7:
				x = 0
				y += 1
			try:
				button = gtk.Button()
				#button.set_relief(gtk.RELIEF_NONE)
				smilieImage = gtk.Image()
				if theme.getSmiley( i ).is_static_image():
					smilieImage.set_from_pixbuf( theme.getSmiley( i ).get_static_image() )
				else:
					smilieImage.set_from_animation( theme.getSmiley( i ) )
				button.set_image( smilieImage )
				button.connect( "clicked" , self.clicked , i )
				table.attach( button , x , x+1 , y , y+1 )
			except:
				x -= 1
			x += 1

		table.show_all()

		self.add( table )
		self.connect( 'delete-event' , self.on_delete_event )
		self.connect( 'leave-notify-event' , self.on_leave_notify_event )
		self.connect( 'enter-notify-event' , self.on_enter_notify_event )

		self.tag = None

	def on_leave_notify_event(self, *args):
		if not self.tag and not self.closed:
			self.tag = timeout_add( 500, self.hide )

	def on_enter_notify_event(self, *args):
		if ( self.tag ):
			source_remove( self.tag )
			self.tag = None

	def on_delete_event( self , *args ):
		self.hide()
		self.closed = True
		return True

	def clicked( self , button , smilie ):
		self.hide()
		self.callback( smilie )

	def show( self ):
		gtk.Window.show( self )
		self.tag = None
		self.closed = False

	def hide( self ):
		gtk.Window.hide( self )
		if ( self.tag ):
			source_remove( self.tag )
			self.tag = None
		self.closed = True
